exclude :test_feed, 'fails, ENOTIME to investigate'
exclude :test_feed_before_first_next, 'fails, ENOTIME to investigate'
exclude :test_feed_mixed, 'fails, ENOTIME to investigate'
exclude :test_feed_yielder, 'fails, ENOTIME to investigate'
exclude :test_initialize_copy, 'fails, ENOTIME to investigate'
exclude :test_loop_return_value, 'fails, ENOTIME to investigate'
exclude :test_nested_iteration, 'fails, ENOTIME to investigate'
exclude :test_next, 'fails, ENOTIME to investigate'
exclude :test_next_after_stop, 'fails, ENOTIME to investigate'
exclude :test_next_after_stopiteration, 'fails, ENOTIME to investigate'
exclude :test_next_rewind, 'fails, ENOTIME to investigate'
exclude :test_next_values, 'fails, ENOTIME to investigate'
exclude :test_peekmake, 'fails, ENOTIME to investigate'
exclude :test_peek, 'fails, ENOTIME to investigate'
exclude :test_peek_for_enumerator_objects, 'fails, ENOTIME to investigate'
exclude :test_peek_modify, 'fails, ENOTIME to investigate'
exclude :test_peek_values, 'fails, ENOTIME to investigate'
exclude :test_peek_values_modify, 'fails, ENOTIME to investigate'
exclude :test_stop_result, 'fails, ENOTIME to investigate'
exclude :test_rewind_clear_feed, 'fails, ENOTIME to investigate'
