exclude :test_class_build_no_mkrf_passes_args,  "tries to skip ~ in version string"
exclude :test_class_build,  "tries to skip ~ in version string"
exclude :test_class_build_with_args,  "tries to skip ~ in version string"
exclude :test_class_no_openssl_override,  "*probably* tries to skip ~ in version string"
