exclude :test_next, 'fails, ENOTIME to investigate'
exclude :test_next_after_stopiteration, 'fails, ENOTIME to investigate'
exclude :test_next_rewind, 'fails, ENOTIME to investigate'
exclude :test_next_values, 'fails, ENOTIME to investigate'
exclude :test_peek, 'fails, ENOTIME to investigate'
exclude :test_peek_values, 'fails, ENOTIME to investigate'
exclude :test_stop_result, 'fails, ENOTIME to investigate'
