exclude :test_execute_regenerate_binstubs, 'depends on source tree'
exclude :test_remove_old_lib_files, 'depends on source tree'
exclude :test_execute_no_regenerate_binstubs, 'depends on source tree'
exclude :test_pem_files_in, 'depends on source tree'
exclude :test_show_release_notes, 'depends on source tree'
exclude :test_install_lib, 'depends on source tree'
exclude :test_rb_files_in, 'depends on source tree'
exclude :test_execute_informs_about_installed_executables, 'needs root to install a gem in the system'
exclude :test_install_default_bundler_gem_with_force_flag, 'needs root to install a gem in the system'
exclude :test_install_default_bundler_gem, 'needs root to install a gem in the system'
exclude :test_env_shebang_flag, 'needs root to install a gem in the system'
