exclude :test_local_stack_on_exception, 'no MJIT_HEADER'
exclude :test_inlined_builtin_methods, 'no MJIT_HEADER'
exclude :test_compile_insn_newrange, 'no MJIT_HEADER'
exclude :test_compile_insn_putspecialobject, 'no MJIT_HEADER'
exclude :test_compile_insn_setspecial, 'no MJIT_HEADER'
exclude :test_compile_insn_splatarray, 'no MJIT_HEADER'
exclude :test_inlined_undefined_ivar, 'no MJIT_HEADER'
exclude :test_clean_so, 'no MJIT_HEADER'
exclude :test_compile_insn_branchnil, 'no MJIT_HEADER'
exclude :test_compile_insn_duphash, 'no MJIT_HEADER'
exclude :test_inlined_exivar, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_rel, 'no MJIT_HEADER'
exclude :test_compile_insn_constant, 'no MJIT_HEADER'
exclude :test_inlined_c_method, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_cmp, 'no MJIT_HEADER'
exclude :test_compile_insn_defined, 'no MJIT_HEADER'
exclude :test_compile_insn_pop, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_ltlt, 'no MJIT_HEADER'
exclude :test_compile_insn_expandarray, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_str_uminus, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_invokebuiltin_delegate_leave, 'no MJIT_HEADER'
exclude :test_compile_insn_putself, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_calc, 'no MJIT_HEADER'
exclude :test_compile_insn_jump_branchif, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_newarray_max, 'no MJIT_HEADER'
exclude :test_compile_insn_adjuststack, 'no MJIT_HEADER'
exclude :test_compile_insn_throw, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_or, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_length_size, 'no MJIT_HEADER'
exclude :test_compile_insn_putobject, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_succ, 'no MJIT_HEADER'
exclude :test_local_stack_with_sp_motion_by_blockargs, 'no MJIT_HEADER'
exclude :test_compile_insn_global, 'no MJIT_HEADER'
exclude :test_compile_insn_local, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_and, 'no MJIT_HEADER'
exclude :test_compile_insn_swap_topn, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_aset, 'no MJIT_HEADER'
exclude :test_attr_reader, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_str_freeze, 'no MJIT_HEADER'
exclude :test_compile_insn_dup, 'no MJIT_HEADER'
exclude :test_stack_pointer_with_assignment, 'no MJIT_HEADER'
exclude :test_mjit_output, 'no MJIT_HEADER'
exclude :test_compile_insn_send, 'no MJIT_HEADER'
exclude :test_compile_insn_invokeblock_leave, 'no MJIT_HEADER'
exclude :test_compile_insn_getconstant_path, 'no MJIT_HEADER'
exclude :test_compile_insn_newarraykwsplat, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_send_without_block, 'no MJIT_HEADER'
exclude :test_compile_insn_checkmatch, 'no MJIT_HEADER'
exclude :test_compile_insn_putnil, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_empty_p, 'no MJIT_HEADER'
exclude :test_program_counter_with_regexpmatch, 'no MJIT_HEADER'
exclude :test_compile_multiple_values_case, 'no MJIT_HEADER'
exclude :test_compile_insn_objtostring, 'no MJIT_HEADER'
exclude :test_inlined_setivar_frozen, 'no MJIT_HEADER'
exclude :test_compile_insn_getblockparamproxy, 'no MJIT_HEADER'
exclude :test_jit_failure, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_nil_p, 'no MJIT_HEADER'
exclude :test_compile_insn_putstring_concatstrings_objtostring, 'no MJIT_HEADER'
exclude :test_jump_to_precompiled_branch, 'no MJIT_HEADER'
exclude :test_compile_insn_dupn, 'no MJIT_HEADER'
exclude :test_builtin_frame_omitted_inlining, 'no MJIT_HEADER'
exclude :test_pushed_values_with_opt_aref_with, 'no MJIT_HEADER'
exclude :test_compile_insn_invokesuper, 'no MJIT_HEADER'
exclude :test_compile_insn_classvariable, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_aref_with, 'no MJIT_HEADER'
exclude :test_compile_insn_checkmatch_opt_case_dispatch, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_newarray_min, 'no MJIT_HEADER'
exclude :test_pushed_values_with_opt_aset_with, 'no MJIT_HEADER'
exclude :test_compile_insn_newarray, 'no MJIT_HEADER'
exclude :test_compile_insn_toregexp, 'no MJIT_HEADER'
exclude :test_compile_insn_concatarray, 'no MJIT_HEADER'
exclude :test_compile_insn_newhash, 'no MJIT_HEADER'
exclude :test_compile_insn_instancevariable, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_aref, 'no MJIT_HEADER'
exclude :test_compile_insn_intern_duparray, 'no MJIT_HEADER'
exclude :test_compile_insn_invokebuiltin, 'no MJIT_HEADER'
exclude :test_not_cancel_by_tracepoint_class, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_regexpmatch2, 'no MJIT_HEADER'
exclude :test_compile_insn_setn, 'no MJIT_HEADER'
exclude :test_compile_insn_nop, 'no MJIT_HEADER'
exclude :test_catching_deep_exception, 'no MJIT_HEADER'
exclude :test_block_handler_with_possible_frame_omitted_inlining, 'no MJIT_HEADER'
exclude :test_compile_insn_branchunless, 'no MJIT_HEADER'
exclude :test_newarraykwsplat_on_stack, 'no MJIT_HEADER'
exclude :test_lambda_longjmp, 'no MJIT_HEADER'
exclude :test_compile_opt_pc, 'no MJIT_HEADER'
exclude :test_compile_insn_checkkeyword, 'no MJIT_HEADER'
exclude :test_frame_omitted_inlining, 'no MJIT_HEADER'
exclude :test_compile_insn_definemethod_definesmethod, 'no MJIT_HEADER'
exclude :test_inlined_getconstant, 'no MJIT_HEADER'
exclude :test_compile_insn_getspecial, 'no MJIT_HEADER'
exclude :test_compile_insn_once, 'no MJIT_HEADER'
exclude :test_compile_insn_opt_not, 'no MJIT_HEADER'
exclude :test_compile_insn_blockparam, 'no MJIT_HEADER'
