exclude :test_base_dir_default, 'depends on source tree'
exclude :test_self_from_yaml_cleans_up_defaultkey, 'failure against ruby-rubygems, version mismatch'
exclude :test_self_from_yaml_cleans_up_defaultkey_from_newer_192, 'failure against ruby-rubygems, version mismatch'
