exclude :test_line, 'fails, ENOTIME to investigate'
exclude :test_lineno, 'fails, ENOTIME to investigate'
exclude :test_inspect_shows_headers_when_available, 'fails, ENOTIME to investigate'
exclude :test_readline, 'fails, ENOTIME to investigate'
