exclude :test_self_prefix, 'depends on source tree'
exclude :test_default_path_missing_vendor, 'depends on source tree'
exclude :test_default_path, 'depends on source tree'
exclude :test_default_path_user_home, 'depends on source tree'
exclude :test_default_path_vendor_dir, 'depends on source tree'
exclude :test_use_gemdeps, 'failure against ruby2.7, cant find gem bundler (= 2.1.2)'
exclude :test_self_find_files_with_gemfile, 'failure against ruby2.7, cant find gem bundler (= 2.1.2)'
exclude :test_auto_activation_of_used_gemdeps_file, 'failure against ruby2.7, cant find gem bundler (= 2.1.2)'
exclude :test_auto_activation_of_specific_gemdeps_file, 'failure against ruby2.7, cant find gem bundler (= 2.1.2)'
exclude :test_use_gemdeps_automatic, 'failure against ruby2.7, cant find gem bundler (= 2.1.2)'
exclude :test_self_use_gemdeps, 'failure against ruby2.7, cant find gem bundler (= 2.1.2)'
exclude :test_use_gemdeps_specific, 'failure against ruby2.7, cant find gem bundler (= 2.1.2)'
exclude :test_use_gemdeps_missing_gem, 'failure against ruby-rubygems, version mismatch'
