exclude :test_eof?, 'fails, ENOTIME to investigate'
exclude :test_open_encoding_invalid, 'fails, ENOTIME to investigate'
exclude :test_shift, 'fails, ENOTIME to investigate'
exclude :test_shift_and_each, 'fails, ENOTIME to investigate'
